Documentation
¶
Index ¶
- func DerefString(s *string) string
- func HashSystemSecretSHA256(secret string) (string, error)
- func NilIfEmpty(s string) *string
- func ProcessInBatches[T any](items []T, batchSize int, processFn func(batch []T) error) error
- func StrPtr(s string) *string
- func VerifySystemSecretSHA256(secret, encodedHash string) (bool, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DerefString ¶
DerefString returns the value of a string pointer or empty string if nil
func HashSystemSecretSHA256 ¶
HashSystemSecretSHA256 generates a salted SHA256 hash of the system secret. Returns format: hex_salt:hex_hash
func NilIfEmpty ¶
NilIfEmpty returns nil if the string is empty, otherwise returns a pointer to the string
func ProcessInBatches ¶
ProcessInBatches processes items in batches of the given size, calling processFn for each batch. Returns an error if any batch fails.
func VerifySystemSecretSHA256 ¶
VerifySystemSecretSHA256 verifies a system secret against a salted SHA256 hash. Expected format: hex_salt:hex_hash
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.